@@ -39,4 +39,6 @@ STATUS_CHOICES = OPTIONS.get('STATUS_CHOICES', (
 STATUS_CHOICES_START = STATUS_CHOICES[0][0]
 STATUS_CHOICES_FINISH = STATUS_CHOICES[-1][0]
 
-MESSAGE_SUCCESS = MESSAGES.get('SUCCESS', 'Order created')
\ No newline at end of file
+MESSAGE_SUCCESS = MESSAGES.get('SUCCESS', 'Order created')
+MESSAGE_NEW_ORDER_USER = MESSAGES.get('NEW_ORDER_USER', 'New Order')
+MESSAGE_NEW_ORDER_ADMIN = MESSAGES.get('NEW_ORDER_ADMIN', 'New Order')
\ No newline at end of file
